==> jc-1.4.0.tar.gz: java/lang/VMSystem.h <==
// final class java.lang.VMSystem

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4d1cebae0bdda058 java_lang_VMSystem

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMSystem_H_
#define _JC_java_lang_VMSystem_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_VMSystem$sub_refs	_jc_java_lang_VMSystem$sub_refs;
typedef struct _jc_java_lang_VMSystem$sub_nonrefs	_jc_java_lang_VMSystem$sub_nonrefs;
typedef struct _jc_java_lang_VMSystem$refs	_jc_java_lang_VMSystem$refs;
typedef struct _jc_java_lang_VMSystem$nonrefs	_jc_java_lang_VMSystem$nonrefs;
typedef struct _jc_java_lang_VMSystem$object	_jc_java_lang_VMSystem$object;

typedef const struct _jc_java_lang_VMSystem$vmethods	_jc_java_lang_VMSystem$vmethods;
typedef const struct _jc_java_lang_VMSystem$vtable	_jc_java_lang_VMSystem$vtable;
typedef const struct _jc_java_lang_VMSystem$vtype	_jc_java_lang_VMSystem$vtype;

// Constructors
extern void _jc_java_lang_VMSystem$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMSystem$object *);

// Static methods
extern void _jc_java_lang_VMSystem$method$arraycopy$4286a72d57744cd8(_jc_env *, struct _jc_java_lang_Object$object *, jint, struct _jc_java_lang_Object$object *, jint, jint);
extern jlong _jc_java_lang_VMSystem$method$currentTimeMillis$f4fdeb31d00e9185(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_java_lang_VMSystem$method$getenv$01721b57e9ee7401(_jc_env *, struct _jc_java_lang_String$object *);
extern jint _jc_java_lang_VMSystem$method$identityHashCode$08e9f770468404df(_jc_env *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_io_PrintStream$object *_jc_java_lang_VMSystem$method$makeStandardErrorStream$92b83c8a2b351cdd(_jc_env *);
extern struct _jc_java_io_InputStream$object *_jc_java_lang_VMSystem$method$makeStandardInputStream$2f00da09046520c0(_jc_env *);
extern struct _jc_java_io_PrintStream$object *_jc_java_lang_VMSystem$method$makeStandardOutputStream$b8adf244b00bf947(_jc_env *);
extern void _jc_java_lang_VMSystem$method$setErr$40c9877d93b89051(_jc_env *, struct _jc_java_io_PrintStream$object *);
extern void _jc_java_lang_VMSystem$method$setIn$ae3f89738f69544b(_jc_env *, struct _jc_java_io_InputStream$object *);
extern void _jc_java_lang_VMSystem$method$setOut$ac549d8338b46119(_jc_env *, struct _jc_java_io_PrintStream$object *);

// Virtual methods structure
struct _jc_java_lang_VMSystem$vmethods {
};

// Vtable
struct _jc_java_lang_VMSystem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMSystem$vmethods	java_lang_VMSystem;
};

// Vtype
struct _jc_java_lang_VMSystem$vtype {
	_jc_type			type;
	_jc_java_lang_VMSystem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMSystem$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMSystem$refs {
    _jc_java_lang_VMSystem$sub_refs	java_lang_VMSystem;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMSystem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMSystem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMSystem$sub_nonrefs	java_lang_VMSystem;
};

// Object instance structure
struct _jc_java_lang_VMSystem$object {
	_jc_java_lang_VMSystem$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMSystem$vtype	*vtype;
	_jc_java_lang_VMSystem$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMSystem$vtype _jc_java_lang_VMSystem$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMSystem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMSystem$class_object;

#endif	/* _JC_java_lang_VMSystem_H_ */

==> jc-1.4.6.tar.gz: java/lang/VMSystem.h <==
// final class java.lang.VMSystem

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4d1cebae0bdda058 java_lang_VMSystem

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMSystem_H_
#define _JC_java_lang_VMSystem_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_VMSystem$sub_refs	_jc_java_lang_VMSystem$sub_refs;
typedef struct _jc_java_lang_VMSystem$sub_nonrefs	_jc_java_lang_VMSystem$sub_nonrefs;
typedef struct _jc_java_lang_VMSystem$refs	_jc_java_lang_VMSystem$refs;
typedef struct _jc_java_lang_VMSystem$nonrefs	_jc_java_lang_VMSystem$nonrefs;
typedef struct _jc_java_lang_VMSystem$object	_jc_java_lang_VMSystem$object;

typedef const struct _jc_java_lang_VMSystem$vmethods	_jc_java_lang_VMSystem$vmethods;
typedef const struct _jc_java_lang_VMSystem$vtable	_jc_java_lang_VMSystem$vtable;
typedef const struct _jc_java_lang_VMSystem$vtype	_jc_java_lang_VMSystem$vtype;

// Constructors
extern void _jc_java_lang_VMSystem$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMSystem$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_lang_VMSystem$method$arraycopy$4286a72d57744cd8(_jc_env *, struct _jc_java_lang_Object$object *, jint, struct _jc_java_lang_Object$object *, jint, jint) _JC_JCNI_ATTR;
extern jlong _jc_java_lang_VMSystem$method$currentTimeMillis$f4fdeb31d00e9185(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_lang_VMSystem$method$getenv$01721b57e9ee7401(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jint _jc_java_lang_VMSystem$method$identityHashCode$08e9f770468404df(_jc_env *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_PrintStream$object *_jc_java_lang_VMSystem$method$makeStandardErrorStream$92b83c8a2b351cdd(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_java_lang_VMSystem$method$makeStandardInputStream$2f00da09046520c0(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_io_PrintStream$object *_jc_java_lang_VMSystem$method$makeStandardOutputStream$b8adf244b00bf947(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMSystem$method$setErr$40c9877d93b89051(_jc_env *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMSystem$method$setIn$ae3f89738f69544b(_jc_env *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMSystem$method$setOut$ac549d8338b46119(_jc_env *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_VMSystem$vmethods {
};

// Vtable
struct _jc_java_lang_VMSystem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMSystem$vmethods	java_lang_VMSystem;
};

// Vtype
struct _jc_java_lang_VMSystem$vtype {
	_jc_type			type;
	_jc_java_lang_VMSystem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMSystem$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMSystem$refs {
    _jc_java_lang_VMSystem$sub_refs	java_lang_VMSystem;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMSystem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMSystem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMSystem$sub_nonrefs	java_lang_VMSystem;
};

// Object instance structure
struct _jc_java_lang_VMSystem$object {
	_jc_java_lang_VMSystem$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMSystem$vtype	*vtype;
	_jc_java_lang_VMSystem$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMSystem$vtype _jc_java_lang_VMSystem$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMSystem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMSystem$class_object;

#endif	/* _JC_java_lang_VMSystem_H_ */
